import { useEffect } from "react";

// Bundler is configured to load this as a processed minified CSS-string
// @ts-ignore
import styles from "./styles.css";

let styleElement: HTMLStyleElement | undefined;

declare const __webpack_nonce__: string | undefined;
let nonce: string | undefined;

/**
 * Returns a nonce hash included by Webpack or the one defined manually by developer.
 * https://developer.mozilla.org/en-US/docs/Web/HTML/Global_attributes/nonce
 * https://webpack.js.org/guides/csp/
 */
const getNonce = (): string | undefined => {
  if (nonce) return nonce;
  if (typeof __webpack_nonce__ !== "undefined") return __webpack_nonce__;
  return undefined;
};

/**
 * Signs the style tag with a base64-encoded string (nonce) to conforms to Content Security Policies.
 * This function has to be invoked before any picker is rendered if you aren't using Webpack for CSP.
 */
const setNonce = (hash: string): void => {
  nonce = hash;
};

/**
 * Injects CSS code into the document's <head>
 */
export const useStyleSheet = (): void => {
  useEffect(() => {
    if (typeof document !== "undefined" && !styleElement) {
      styleElement = document.createElement("style");
      styleElement.innerHTML = styles;

      // Conform to CSP rules by setting `nonce` attribute to the inline styles
      const nonce = getNonce();
      if (nonce) styleElement.setAttribute("nonce", nonce);

      document.head.appendChild(styleElement);
    }
  }, []);
};
